==> haskell-socks-0.6.1-85-x86_64.pkg.tar.zst: usr/share/haskell/register/haskell-socks.sh <==
#!/bin/sh
export PATH='/usr/local/sbin:/usr/local/bin:/usr/bin:/usr/bin/site_perl:/usr/bin/vendor_perl:/usr/bin/core_perl'
echo 'name:                 socks
version:              0.6.1
visibility:           public
id:                   socks-0.6.1-J8a23OWpphJ4Gffn4sVJqw
key:                  socks-0.6.1-J8a23OWpphJ4Gffn4sVJqw
license:              BSD-3-Clause
copyright:            Vincent Hanquez <vincent@snarc.org>
maintainer:           Vincent Hanquez <vincent@snarc.org>
author:               Vincent Hanquez <vincent@snarc.org>
stability:            experimental
homepage:             http://github.com/vincenthz/hs-socks
synopsis:             Socks proxy (ver 5)
description:          Socks proxy (version 5) implementation.
category:             Network
abi:                  56fc16ff0a0c11c7f1dcd0921a632678
exposed:              True
exposed-modules:
    Network.Socks5 Network.Socks5.Lowlevel Network.Socks5.Types

hidden-modules:
    Network.Socks5.Wire Network.Socks5.Conf Network.Socks5.Command
    Network.Socks5.Parse

import-dirs:          /usr/lib/ghc-8.10.3/site-local/socks-0.6.1
library-dirs:         /usr/lib/ghc-8.10.3/site-local/socks-0.6.1
dynamic-library-dirs: /usr/lib
data-dir:             /usr/share/x86_64-linux-ghc-8.10.3/socks-0.6.1
hs-libraries:         HSsocks-0.6.1-J8a23OWpphJ4Gffn4sVJqw
depends:
    base-4.14.1.0 basement-0.0.11-CejmV4k3OtGGKPkDYOlSof
    bytestring-0.10.12.0 cereal-0.5.8.1-GAgNOTi0dTnED5BVJ0WdTc
    network-3.1.2.1-IKBKB32QfOpBaCdBzK7XSA

haddock-interfaces:   /usr/share/doc/haskell-socks/html/socks.haddock
haddock-html:         /usr/share/doc/haskell-socks/html
' | '/usr/bin/ghc-pkg' 'update' '--force' '-' '--global' '--no-user-package-db' "$@"

==> haskell-socks-0.6.1-91-x86_64.pkg.tar.zst: usr/share/haskell/register/haskell-socks.sh <==
#!/bin/sh
export PATH='/usr/local/sbin:/usr/local/bin:/usr/bin:/usr/bin/site_perl:/usr/bin/vendor_perl:/usr/bin/core_perl'
echo 'name:                 socks
version:              0.6.1
visibility:           public
id:                   socks-0.6.1-Cxj036JtfWYLaVJfTfX135
key:                  socks-0.6.1-Cxj036JtfWYLaVJfTfX135
license:              BSD-3-Clause
copyright:            Vincent Hanquez <vincent@snarc.org>
maintainer:           Vincent Hanquez <vincent@snarc.org>
author:               Vincent Hanquez <vincent@snarc.org>
stability:            experimental
homepage:             http://github.com/vincenthz/hs-socks
synopsis:             Socks proxy (ver 5)
description:          Socks proxy (version 5) implementation.
category:             Network
abi:                  a8ddf499ac628a4c9ec2571e5e6d6888
exposed:              True
exposed-modules:
    Network.Socks5 Network.Socks5.Lowlevel Network.Socks5.Types

hidden-modules:
    Network.Socks5.Wire Network.Socks5.Conf Network.Socks5.Command
    Network.Socks5.Parse

import-dirs:          /usr/lib/ghc-8.10.4/site-local/socks-0.6.1
library-dirs:         /usr/lib/ghc-8.10.4/site-local/socks-0.6.1
dynamic-library-dirs: /usr/lib
data-dir:             /usr/share/x86_64-linux-ghc-8.10.4/socks-0.6.1
hs-libraries:         HSsocks-0.6.1-Cxj036JtfWYLaVJfTfX135
depends:
    base-4.14.1.0 basement-0.0.11-CejmV4k3OtGGKPkDYOlSof
    bytestring-0.10.12.0 cereal-0.5.8.1-GAgNOTi0dTnED5BVJ0WdTc
    network-3.1.2.1-JytrvOyFuvxLl7icZfUbp0

haddock-interfaces:   /usr/share/doc/haskell-socks/html/socks.haddock
haddock-html:         /usr/share/doc/haskell-socks/html
' | '/usr/bin/ghc-pkg' 'update' '--force' '-' '--global' '--no-user-package-db' "$@"
